==> docx4j-openxml-objects-8.1.3-sources.jar: org/docx4j/com/microsoft/schemas/office/webextensions/taskpanes_2010_11/CTOsfTaskpanes.java <==

package org.docx4j.com.microsoft.schemas.office.webextensions.taskpanes_2010_11;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;

import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_OsfTaskpanes complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_OsfTaskpanes"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="taskpane" type="{http://schemas.microsoft.com/office/webextensions/taskpanes/2010/11}CT_OsfTaskpane" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_OsfTaskpanes", propOrder = {
    "taskpane"
})
@XmlRootElement(name="taskpanes")
public class CTOsfTaskpanes implements Child
{

    protected List<CTOsfTaskpane> taskpane;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the taskpane property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the taskpane property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTaskpane().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTOsfTaskpane }
     * 
     * 
     */
    public List<CTOsfTaskpane> getTaskpane() {
        if (taskpane == null) {
            taskpane = new ArrayList<CTOsfTaskpane>();
        }
        return this.taskpane;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-11.5.4-sources.jar: org/docx4j/com/microsoft/schemas/office/webextensions/taskpanes_2010_11/CTOsfTaskpanes.java <==

package org.docx4j.com.microsoft.schemas.office.webextensions.taskpanes_2010_11;

import java.util.ArrayList;
import java.util.List;

import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;

import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_OsfTaskpanes complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_OsfTaskpanes"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="taskpane" type="{http://schemas.microsoft.com/office/webextensions/taskpanes/2010/11}CT_OsfTaskpane" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_OsfTaskpanes", propOrder = {
    "taskpane"
})
@XmlRootElement(name="taskpanes")
public class CTOsfTaskpanes implements Child
{

    protected List<CTOsfTaskpane> taskpane;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the taskpane property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the taskpane property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTaskpane().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTOsfTaskpane }
     * 
     * 
     */
    public List<CTOsfTaskpane> getTaskpane() {
        if (taskpane == null) {
            taskpane = new ArrayList<CTOsfTaskpane>();
        }
        return this.taskpane;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
